#!/usr/bin/env perl
#-------------------------------------------------------------------------------
# PROGRAMM.pl                                    (C) 2024 T.Birnthaler OSTC GmbH
# BESCHREIBUNG
# $Id:$
#-------------------------------------------------------------------------------
# Warnungen und Fehlermeldungen verschaerfen
use strict;
use warnings;         # Oder "-w" in Shee-Bang-Zeile oben
#use diagnostics;     # Ausfuehrliche Fehlermeldung mit Erklaerung
use Carp;             # carp/croak/confess statt warn/die
use English;          # Lange Namen fuer Spezialvariablen ($_/@ = $ARG/@ARG)

# Mindestversion erzwingen
use 5.6.1;
use v5.6.1;
use 5.006_001;
#use feature ":5.6.1";   # Geht nicht in 5.20.1

# Zusaetzliche Eigenschaften aktivieren
use utf8;                    # ???
use feature "switch";        # Damit "given ... when ... default" funktioniert
use feature "say";           # Damit "say" funktioniert
use feature "state";         # Damit "state" funktioniert
#use feature "mro";          # Geht evtl. nicht ab 5.20.1
#use feature "sort";         # Geht evtl. nicht ab 5.20.1
#use common::sense;           # Geht evtl. nicht ab 5.xx.y

# Konstante definieren
use constant PI1 => 3.141592;
sub PI2 { return 3.141592; }
#define("PI3", 3.141592);

# Standardmodule
use Data::Dumper;                   # Variableninhalt formatiert ausgeben
use File::Basename;                 # qw( basename dirname ); ueberfluessig
use File::Find;                     # Dateisuche analog "find"
#use Getopt::Std;                   # Getopt::Long kann deutlich mehr
use Getopt::Long qw( :config no_ignore_case );   # GROSS/kleinschreibung beachten
#use Log::Log4perl qw( :easy );      # Anwendungs-Logging
use Math::Trig;                     # qw ( :pi ); ueberfluessig
use POSIX qw/ strftime /;           # ???
use Time::Local qw/ timelocal /;    # Umwandlung Datum+Uhrzeit --> Timestamp
use Time::HiRes;                    # Zeitmessung mit hoher Aufloesung
use Sys::Syslog;                    # System-Logging
#use Spreadsheet::WriteExcel;        # Excel-Tabelle erstellen

#-------------------------------------------------------------------------------
# Beispiel fuer Konstante aus Modul Math::Trig
#-------------------------------------------------------------------------------
print "PI1: ", PI1, "\n";
print "PI2: ", PI2, "\n";
#print "PI3: ", PI3, "\n";
print "PI4: ", Math::Trig::pi, "\n";

#-------------------------------------------------------------------------------
# Programmspezifisch loggen
#-------------------------------------------------------------------------------
# Logdatei
my $logfile = "/tmp/log4perl.log";

# Wie soll standardmaessig geloggt werden?
#Log::Log4perl->easy_init({
#	level => $ERROR,
#	file  => "> $logfile",
#});
#Log::Log4perl->easy_init($DEBUG);

#-------------------------------------------------------------------------------
# System-Logging nutzen
#-------------------------------------------------------------------------------
openlog($0, "cons,pid", "user");
syslog("info", "%s", "Weiterer Test");
syslog("mail|warning", "Besserer Test: %d", time);
syslog("debug", "Letzter Test");
closelog();

#-------------------------------------------------------------------------------
# File::Find
#-------------------------------------------------------------------------------
my @dirs = ("/etc", "/tmp", "/home");
sub select {
	print "DIR:  $File::Find::dir\n" if (-d $_);
	print "FILE: $_\n" if (-f $_);                  # automatisch chdir
	print "PATH: $File::Find::name\n";
	printf("%7d Bytes, Zeit: %6.2f: %s\n", -s $_, -A $_, $_);
}
File::Find::find(\&select, @dirs);

#-------------------------------------------------------------------------------
# Getopt::Long
#-------------------------------------------------------------------------------
# Optionen-Variablen
my $dbg  = 0;
my $help = 0;
my $test = 0;
my $tttt = 0;
my $verb = 0;
my $file = "/tmp/xxx.txt";
my $zone = 0;

# Argumente vor Options-Erkennung ausgeben
print "Argumente: @ARGV\n" if (@ARGV);

# Optionen einlesen
GetOptions (
    "debug"    => \$dbg,   # flag   
    "file=s"   => \$file,  # string         
    "help"     => \$help,  # flag           
    "test"     => \$test,  # flag           
    "tttt"     => \$tttt,  # flag           
    "verbose"  => \$verb,  # flag           
    "zone"     => \$zone,  # flag           
) or &Usage("wrong option");

# Hilfe ausgeben?
&Usage("") if ($help);

# Optionen ausgeben (nur zum Debugging)
print "Option --debug:   $dbg\n";
print "Option --file:    $file\n";
print "Option --test:    $test\n";
print "Option --tttt:    $tttt\n";
print "Option --verbose: $verb\n";
print "Option --zone:    $zone\n";

# Argumente nach Options-Erkennung ausgeben
print "Argumente: @ARGV\n" if (@ARGV);

#-------------------------------------------------------------------------------
# Usage-Meldung + Abbruch
#-------------------------------------------------------------------------------
sub Usage
{
	my ($msg) = @_;

	*STDOUT = *STDERR;
	print "ERROR: $msg\n" if ($msg);
	print "USAGE: ", basename($0), "\n";
	print "       Macht dies und das...\n";
	print "       --debug      Debugging-Meldungen\n";
	print "       --file FILE  Datei angeben\n";
	print "       --help       Hilfe (diese Usage-Meldung)\n";
	print "       --test       Test\n";
	print "       --tttt       Tttt\n";
	print "       --verbose    Ausfuehrliche Meldungen\n";
	print "       --zone       Zone\n";
	exit(1);
}

#-------------------------------------------------------------------------------
# Einfacher Dump von Array, Hash, Ergebnis von Funktions-Aufruf, Rechen-Ergebnis
#-------------------------------------------------------------------------------
my @a = (1, 2, 3);
my %h = ("a" => 1, "b" => 2, "c" => 3);
sub f { return 123; }
my $n = 100;

print "ARRAY: @a\n";
print "HASH: @{[%h]}\n";
print "FUNC: ${\f()}\n";
print "EXPR: ${\($n * 5 + 1)}\n";

#-------------------------------------------------------------------------------
# Beispiel fuer Dump einer Datenstruktur
#-------------------------------------------------------------------------------
my %hash = ( tom => 18, hans => 36, rick => 75 );
print Data::Dumper->Dump([ \@ARGV, \$zone, \%hash ]);
print Dumper([ \@ARGV, \$zone, \%hash ]);

#-------------------------------------------------------------------------------
# Beispiel fuer Switch-Anweisung ("when" verwendet Smart-Match-Operator "~~")
#-------------------------------------------------------------------------------
given ($logfile)   # Std: $_
{
	when(/abc/) { print "abc\n"; }
	when("xyz") { print "xyz\n"; }
	when(123)   { print "123\n"; }
	default     { print "Wert: '$_'\n"; }
}
